Index: lisp/ChangeLog
===================================================================
RCS file: /pack/xemacscvs/XEmacs/xemacs/lisp/ChangeLog,v
retrieving revision 1.266.2.88
diff -u -0 -r1.266.2.88 ChangeLog
--- lisp/ChangeLog	2005/12/07 01:16:46	1.266.2.88
+++ lisp/ChangeLog	2005/12/23 17:18:30
@@ -0,0 +1,6 @@
+2005-12-23  Vin Shelton  <acs@xemacs.org>
+
+	* find-paths.el (paths-emacs-root-p): Add search for package root.
+	* find-paths.el (paths-find-emacs-root): Search for packages in ../XEmacs
+	* find-paths.el (paths-find-emacs-roots): Flatten returned list.
+
@@ -6 +12 @@
-2005-12-03  Vin Shelton <acs@xemacs.org>
+2005-12-03  Vin Shelton  <acs@xemacs.org>
Index: lisp/find-paths.el
===================================================================
RCS file: /pack/xemacscvs/XEmacs/xemacs/lisp/find-paths.el,v
retrieving revision 1.19.2.2
diff -u -r1.19.2.2 find-paths.el
--- lisp/find-paths.el	2002/08/20 11:34:41	1.19.2.2
+++ lisp/find-paths.el	2005/12/23 17:18:33
@@ -108,8 +108,11 @@
    ;; in-place or windows-nt
    (and
     (paths-file-readable-directory-p (paths-construct-path (list directory "lisp")))
-    (paths-file-readable-directory-p (paths-construct-path (list directory "etc"))))))
+    (paths-file-readable-directory-p (paths-construct-path (list directory "etc"))))
 
+   ;; searching for a package directory
+   (paths-file-readable-directory-p (paths-construct-path (list directory "xemacs-packages")))))
+
 (defun paths-root-in-place-p (root)
   "Check if ROOT is an in-place installation root for XEmacs."
   (paths-file-readable-directory-p (paths-construct-path (list root "lisp"))))
@@ -123,9 +126,10 @@
 	      (paths-chase-symlink destination))
 	  file-name)))
 
-(defun paths-find-emacs-root
-  (invocation-directory invocation-name)
-  "Find the run-time root of XEmacs."
+(defun paths-find-emacs-root (invocation-directory invocation-name)
+  "Find the run-time root of XEmacs.
+INVOCATION-DIRECTORY is a directory containing the XEmacs executable.
+INVOCATION-NAME is the name of the executable itself."
   (let* ((executable-file-name (paths-chase-symlink
 				(concat invocation-directory
 					invocation-name)))
@@ -133,11 +137,13 @@
 	 (maybe-root-1 (file-name-as-directory
 			(paths-construct-path '("..") executable-directory)))
 	 (maybe-root-2 (file-name-as-directory
-			(paths-construct-path '(".." "..") executable-directory))))
-    (or (and (paths-emacs-root-p maybe-root-1)
-	     maybe-root-1)
-	(and (paths-emacs-root-p maybe-root-2)
-	     maybe-root-2))))
+			(paths-construct-path '(".." "..") executable-directory)))
+	 (maybe-root-3 (file-name-as-directory
+			(paths-construct-path '(".." ".." "XEmacs") executable-directory))))
+
+    (paths-filter #'paths-emacs-root-p
+		  (list maybe-root-1 maybe-root-2 maybe-root-3))))
+
 
 (defun paths-construct-path (components &optional expand-directory)
   "Convert list of path components COMPONENTS into a path.
@@ -315,8 +321,13 @@
 		(list (file-name-as-directory
 		       configure-prefix-directory)))))
 	 (installation-roots
-	  (paths-filter #'paths-emacs-root-p potential-installation-roots)))
-    (paths-uniq-append invocation-roots
-		       installation-roots)))
+	  (paths-filter #'paths-emacs-root-p potential-installation-roots))
+	 (maybe-not-flat (paths-uniq-append
+			  invocation-roots
+			  installation-roots)))
+    ; flatten the list and return it
+    (if (listp (car maybe-not-flat))
+	(nconc (car maybe-not-flat) (nthcdr 1 maybe-not-flat))
+      maybe-not-flat)))
 
 ;;; find-paths.el ends here

